@@ -4,9 +4,10 @@ import sys
 import os
 import logging
 import logging.handlers
-from Messenger_new.common.variables import LOGGING_LEVEL
+sys.path.append('../')
+from common.variables import LOGGING_LEVEL
+
 
-sys.path.append('../lesson_7')
 
 # создаём формировщик логов (formatter):
 SERVER_FORMATTER = logging.Formatter('%(asctime)s %(levelname)s %(filename)s %(message)s')
